### written by Jihyeon Yun and Jiayin Gao for analyzing Korean data collected with EGG
### May 2020, revised Oct 2020

rm(list = ls(envir = .GlobalEnv), envir = .GlobalEnv)
options(mc.cores = parallel::detectCores())

#################
library(dplyr)
library(tidyr)
library(reshape2)
library(standardize)
library(ggplot2)
library(wesanderson)
library(lmerTest)
library(emmeans)
library(xtable)
library(ggpubr)
library(rpart)
library(rpart.plot)
#################
set.seed(2020)

# path <- "/Users/jgao3/Dropbox/JSPS/Korean_EGG/paper_Korean_EGG/LabPhon_ms"
setwd(path)

output_dir <- "KorEGG_fig"
ifelse(!dir.exists(file.path(path, output_dir)), dir.create(file.path(path, output_dir)), FALSE)

theme_set(theme_minimal(base_size = 20))
labelsex <- c("F" = "Female", "M" = "Male")
colors_all <- c("#FF0000", "#00A08A", "#F2AD00", "#EE82EE", "#00FFFF")
colors_stops <- colors_all[1:4]
ggscatter_font <- font("xlab", size = 20) + font("ylab", size = 20) +
  font("xy.text", size = 15) +
  font("legend.title", size = 20) +
  font("legend.text", size = 15)

#####
#VOT analyses
#####

VOTdat.orig <- read.table("KorEGG_duration_20200509.txt",
                          header=T, sep="\t", comment.char="",fileEncoding='UTF-8')

VOTdat <- VOTdat.orig
VOTdat$speaker <- substr(VOTdat$filename, 1, 4)
VOTdat$sex <- substr(VOTdat$filename, 6, 6)
VOTdat$repetition <- substr(VOTdat$filename, 8, 9)

# vowel context after the onset
VOTdat$nextseg <- NA
for (row in 1:(nrow(VOTdat)-1)) {
  seg <- VOTdat[row, "Segment"]
  nextseg <- VOTdat[row+1, "Segment"]
  VOTdat[row, "nextseg"] <- as.character(nextseg)
}
VOTdat$vowel <- VOTdat$nextseg

VOTdat <- VOTdat[VOTdat$VOTMS < 1000,] #1000+ for VOTMS code for invalid data
VOTdat <- VOTdat[VOTdat$Segment %in% c("p0", "ph", "pp", "mm", "t0", "th", "tt", "nn"),]
VOTdat$onset <- factor(VOTdat$Segment,
                       levels = c("p0", "ph", "pp", "mm", "t0", "th", "tt", "nn"))
levels(VOTdat$onset) <- c("p","ph","p'","m","t","th","t'","n")

VOTdat$manner <- NA
VOTdat[VOTdat$onset %in% c("p","t"),]$manner <- "lenis"
VOTdat[VOTdat$onset %in% c("ph","th"),]$manner <- "aspirated"
VOTdat[VOTdat$onset %in% c("p'","t'"),]$manner <- "fortis"
VOTdat[VOTdat$onset %in% c("m","n"),]$manner <- "nasal"

VOTdat$POA <- NA
VOTdat[VOTdat$onset %in% c("p","ph","p'","m"),]$POA <- "lab"
VOTdat[VOTdat$onset %in% c("t","th","t'","n"),]$POA <- "cor"

VOTdat <- droplevels(VOTdat)

VOTdat <- VOTdat %>% mutate(speaker = factor(speaker),
                    sex = factor(sex),
                    vowel = factor(vowel),
                    manner = factor(manner, levels = c("lenis","aspirated","fortis","nasal")),
                    POA = factor(POA, levels = c("lab", "cor")),
                    repetition = factor(repetition))

# devoiced "nasal" stops
nrow(VOTdat[VOTdat$onset %in% c("m","n")&VOTdat$VOTMS >=0,])/nrow(VOTdat[VOTdat$onset %in% c("m","n"),])
devnas <- VOTdat %>%
  filter(onset %in% c("m","n")&VOTdat$VOTMS >=0)

VOTdat$interval <- VOTdat$interval + 1 #to match with f0 and Oq data
summary(VOTdat)

# raw VOT statistics summary
df <- VOTdat %>%
  group_by(manner) %>%
#  group_by(manner, POA) %>%
  summarize(minVOT = min(VOTMS),
            maxVOT = max(VOTMS),
            meanVOT = mean(VOTMS),
            medVOT = median(VOTMS))
df

# outliers
VOTdat[VOTdat$VOTMS >170,]

#####
#VOT distribution plots
#####
figVOT <- ggplot(VOTdat, aes(x=VOTMS, fill=manner)) +
  geom_histogram(alpha = 0.6, binwidth=5, colour='black', size=0.3) +
  scale_fill_manual(values = colors_stops) +
  labs(x = "VOT (ms)") +
  theme(legend.position = 'top') +
  xlim(-150,170)

ggsave("./KorEGG_fig/figVOT.pdf", figVOT, width = 8, height = 6)

#####
#VOT: LME models
#####

# sum coding for 'manner' and 'vowel'
contrasts(VOTdat$manner) <- contr.sum(length(levels(VOTdat$manner)))
colnames(contrasts(VOTdat$manner)) <- rownames(contrasts(VOTdat$manner))[1:nrow(contrasts(VOTdat$manner))-1]

contrasts(VOTdat$vowel) <- contr.sum(length(levels(VOTdat$vowel)))
colnames(contrasts(VOTdat$vowel)) <- rownames(contrasts(VOTdat$vowel))[1:nrow(contrasts(VOTdat$vowel))-1]

contrasts(VOTdat$POA) <- contr.sum(length(levels(VOTdat$POA)))
colnames(contrasts(VOTdat$POA)) <- rownames(contrasts(VOTdat$POA))[1:nrow(contrasts(VOTdat$POA))-1]

mvot.1 <- lmer(VOTMS ~ manner + (1|speaker) + (1|repetition),
           data=VOTdat, control=lmerControl(optimizer="bobyqa"))
mvot.2 <- lmer(VOTMS ~ manner + POA + (1|speaker) + (1|repetition),
           data=VOTdat, control=lmerControl(optimizer="bobyqa"))
mvot.3 <- lmer(VOTMS ~ manner + POA + vowel + (1|speaker) + (1|repetition),
           data=VOTdat, control=lmerControl(optimizer="bobyqa"))
mvot.4 <- lmer(VOTMS ~ manner + POA + vowel + sex + (1|speaker) + (1|repetition),
           data=VOTdat, control=lmerControl(optimizer="bobyqa"))

anova(mvot.1,mvot.2,mvot.3,mvot.4)

summary(mvot.3) # best fit
## output
print(xtable(coef(summary(mvot.3)),digits=c(2,2,2,2,2,4)))

mvot3.emm <- emmeans(mvot.3, ~ manner | POA)
## output
xtable(mvot3.emm, digits=2)
xtable(pairs(mvot3.emm), digits=2)

#####
#f0 and Oq analyses
#####

EGGdat.orig <- read.table("KorEGG_f0_oq_2SD_durnorm_20200218.txt",
                         header=T, sep="\t", comment.char="", encoding="UTF-8") # Data only within 2 sd of oq_diff
EGGdat <- EGGdat.orig

EGGdat$speaker <- paste(EGGdat$sex, substr(EGGdat$id, 3, 4), sep="")
EGGdat$manner <- recode_factor(EGGdat$manner, "lax" = "lenis", "tense" = "fortis", "none" = "zero")

EGGdat <- EGGdat %>% mutate(speaker = factor(speaker),
                            vowel = factor(vowel),
                            place = factor(place),
                            manner = factor(manner, levels = c("lenis","aspirated","fortis","nasal","zero")))

# Scaling/centralizing f0/OQ
EGGdat$f0_scaled <- scale_by(egg_f0 ~ id, EGGdat)
EGGdat$oq_scaled <- scale_by(degg_oq ~ id, EGGdat)

# F0 in semitones by speaker
toST <- function(x,y){log2(x/y) * 12}
EGGdat <- EGGdat %>%
  group_by(id) %>%
  mutate(f0_st = toST(egg_f0, mean(na.omit(egg_f0))))

#####
#f0 curve plots
#####

# by sex group
df <- EGGdat
figf0agg <- ggplot(df, aes(x = factor(timepoint), y = egg_f0, colour = manner, group = manner)) +
  stat_summary(geom="line",fun.y= mean, size = 1, alpha = 10) +
  stat_summary(fun.data = mean_se, geom = "errorbar", width = 0.3, size = 0.5) +
  ylab("f0 (Hz)") +
  xlab("time point") +
  scale_color_manual(values = colors_all) +
  theme(legend.position = 'top') +
  facet_grid(.~sex, labeller = labeller(sex = labelsex))

ggsave("./KorEGG_fig/figf0agg.pdf", figf0agg, width = 10, height = 6)

# by speaker
df <- EGGdat
figf0sp <- ggplot(df, aes(x = factor(timepoint), y = f0_scaled, colour = manner, group = manner)) +
  stat_summary(geom="line",fun.y= mean, size = 1, alpha = 10) +
  stat_summary(fun.data = mean_se, geom = "errorbar", width = 0.3, size = 0.5) +
  ylab("normalized f0") +
  xlab("time point") +
  scale_color_manual(values = colors_all) +
  theme(legend.position = 'top') +
  facet_wrap( .~speaker)

ggsave("./KorEGG_fig/figf0sp.pdf", figf0sp, width = 10, height = 10)

#####
#Oq curve plots
#####

# by sex group
df <- EGGdat
figOqagg <- ggplot(df, aes(x = factor(timepoint), y = degg_oq, colour = manner, group = manner)) +
  stat_summary(geom="line",fun.y= mean, size = 1, alpha = 10) +
  stat_summary(fun.data = mean_se, geom = "errorbar", width = 0.3, size = 0.5) +
  ylab("Open quotient") +
  xlab("time point") +
  scale_color_manual(values = colors_all) +
  theme(legend.position = 'top') +
  facet_grid(.~sex, labeller = labeller(sex = labelsex))

ggsave("./KorEGG_fig/figOqagg.pdf", figOqagg, width = 10, height = 6)

# by speaker
df <- EGGdat
figOqsp <- ggplot(df, aes(x = factor(timepoint), y = oq_scaled, colour = manner, group = manner)) +
  stat_summary(geom="line",fun.y= mean, size = 1, alpha = 10) +
  stat_summary(fun.data = mean_se, geom = "errorbar", width = 0.3, size = 0.5) +
  ylab("normalized Oq") +
  xlab("time point") +
  scale_color_manual(values = colors_all) +
  theme(legend.position = 'top') +
  facet_wrap( .~speaker)

ggsave("./KorEGG_fig/figOqsp.pdf", figOqsp, width = 10, height = 10)

#####
# Aggregation: over V for f0, timepoints 1-3 for Oq
#####

f0raw_Vmean <- aggregate(egg_f0 ~ filename + interval + sex + speaker + token + place + cons + vowel + rep + manner + place,
                        FUN=mean, data=EGGdat)
f0scl_Vmean <- aggregate(f0_scaled ~ filename + interval + sex + speaker + token + place + cons + vowel + rep + manner + place,
                        FUN=mean, data=EGGdat)
f0st_Vmean <- aggregate(f0_st ~ filename + interval + sex + speaker + token + place + cons + vowel + rep + manner + place,
                       FUN=mean, data=EGGdat)

EGG_Vonset <- EGGdat[EGGdat$timepoint <= 3,]
Oqraw_Vonset <- aggregate(degg_oq ~ filename + interval + sex + speaker + token + place + cons + vowel + rep + manner + place,
                        FUN=mean, data=EGG_Vonset)
Oqscl_Vonset <- aggregate(oq_scaled ~ filename + interval + sex + speaker + token + place + cons + vowel + rep + manner + place,
                        FUN=mean, data=EGG_Vonset)

#####
#f0 distribution plots
#####

#df <- EGGdat
df <- f0scl_Vmean

# skewness
f0skewness <- df %>%
  filter(manner != "zero") %>%
  group_by(manner) %>%
  summarise_at("f0_scaled", list(mean = mean, med = median, sd = sd)) %>%
  mutate(skewness = 3*(mean - med)/sd)
f0skewness

figf0hist <- ggplot(df, aes(x=f0_scaled, fill=manner)) +
  geom_histogram(alpha = 0.6, binwidth = 0.2, colour='black', size=0.3) +
  scale_fill_manual(values = colors_all) +
  labs(x = "normalized f0")  +
  xlim(-4.5,3) +
  theme(legend.position = 'top') +
  facet_grid(.~sex, labeller = labeller(sex = labelsex))

ggsave("./KorEGG_fig/figf0hist.pdf", figf0hist, width = 10, height = 6)

#####
#Oq distribution plots
#####

#df <- EGGdat
df <- Oqscl_Vonset

figOqhist <- ggplot(df, aes(x=oq_scaled, fill=manner)) +
  geom_histogram(alpha = 0.6, binwidth = 0.2, colour='black', size=0.3) +
  scale_fill_manual(values = colors_all) +
  labs(x = "normalized Oq")  +
  theme(legend.position = 'top') +
  facet_grid(.~sex, labeller = labeller(sex = labelsex))

ggsave("./KorEGG_fig/figOqhist.pdf", figOqhist, width = 10, height = 6)


#####
#f0: LME models
#####

# fit to f0_scaled data averaged over all timepoints
df <- f0scl_Vmean
df <- droplevels(df[df$manner != "zero",])

# sum coding for 'manner' and 'vowel'
contrasts(df$manner) <- contr.sum(length(levels(df$manner)))
colnames(contrasts(df$manner)) <- rownames(contrasts(df$manner))[1:nrow(contrasts(df$manner))-1]

contrasts(df$vowel) <- contr.sum(length(levels(df$vowel)))
colnames(contrasts(df$vowel)) <- rownames(contrasts(df$vowel))[1:nrow(contrasts(df$vowel))-1]

contrasts(df$place) <- contr.sum(length(levels(df$place)))
colnames(contrasts(df$place)) <- rownames(contrasts(df$place))[1:nrow(contrasts(df$place))-1]

mf0.1 <- lmer(f0_scaled ~ manner + (1|speaker) + (1|rep),
           data=df, control=lmerControl(optimizer="bobyqa")
           )#,REML = F) #singular fit

mf0.2 <- lmer(f0_scaled ~ manner + vowel + (1|speaker) + (1|rep),
           data=df, control=lmerControl(optimizer="bobyqa")
           )#,REML = F)

mf0.3 <- lmer(f0_scaled ~ manner + vowel + place + (1|speaker) + (1|rep),
           data=df, control=lmerControl(optimizer="bobyqa")
           )#,REML = F) # doesn't improve

mf0.4 <- lmer(f0_scaled ~ manner + vowel + place + sex + (1|speaker) + (1|rep),
           data=df, control=lmerControl(optimizer="bobyqa")
           )#,REML = F) # doesn't improve

anova(mf0.1,mf0.2,mf0.3,mf0.4)

# interaction terms
mf0.2int <- lmer(f0_scaled ~ manner*vowel + (1|speaker) + (1|rep),
              data=df, control=lmerControl(optimizer="bobyqa")
              )#,REML = F) # doesn't improve
anova(mf0.2, mf0.2int)

mf0.3int <- lmer(f0_scaled ~ manner*place + vowel + (1|speaker) + (1|rep),
              data=df, control=lmerControl(optimizer="bobyqa")
)#,REML = F)
anova(mf0.3, mf0.3int)

mf0.4int <- lmer(f0_scaled ~ manner*sex + vowel + place + (1|speaker) + (1|rep),
              data=df, control=lmerControl(optimizer="bobyqa")
              )#,REML = F)
anova(mf0.4, mf0.4int)

# 2 interactions terms included
mf0.5 <- lmer(f0_scaled ~ vowel + manner*place + manner*sex + (1|speaker) + (1|rep),
           data=df, control=lmerControl(optimizer="bobyqa")
           )#,REML = F)

# random slopes for manner
mf0.5.slp <- lmer(f0_scaled ~ vowel + manner*place + (1 + manner |speaker) + (1|rep),
                data=df, control=lmerControl(optimizer="bobyqa")
                )#,REML = F) #singular fit

summary(mf0.5) # best fit
print(xtable(coef(summary(mf0.5)),digits=c(2,2,2,2,2,4)))

mf0.5.emm <- emmeans(mf0.5, ~ manner|sex)
xtable(pairs(mf0.5.emm), digits=2)

#####
#Oq: LME models
#####

# fit to Oq_scaled data first 3 timepoints
df <- Oqscl_Vonset
df <- droplevels(df[df$manner != "zero",])

# sum coding for 'manner' and 'vowel'
contrasts(df$manner) <- contr.sum(length(levels(df$manner)))
colnames(contrasts(df$manner)) <- rownames(contrasts(df$manner))[1:nrow(contrasts(df$manner))-1]

contrasts(df$vowel) <- contr.sum(length(levels(df$vowel)))
colnames(contrasts(df$vowel)) <- rownames(contrasts(df$vowel))[1:nrow(contrasts(df$vowel))-1]

contrasts(df$place) <- contr.sum(length(levels(df$place)))
colnames(contrasts(df$place)) <- rownames(contrasts(df$place))[1:nrow(contrasts(df$place))-1]

# for all participants
mOq.1 <- lmer(oq_scaled ~ manner + (1|speaker),
                 data=df, control=lmerControl(optimizer="bobyqa")
              )#,REML = F)

mOq.2 <- lmer(oq_scaled ~ manner + vowel + (1|speaker),
              data=df, control=lmerControl(optimizer="bobyqa")
              )#,REML = F)

anova(mOq.1,mOq.2)

# interaction terms
mOq.2int <- lmer(oq_scaled ~ manner*vowel + (1|speaker),
                 data=df, control=lmerControl(optimizer="bobyqa")
                 )#,REML = F)
anova(mOq.2, mOq.2int)

# random slopes
mOq.2int.slp <- lmer(oq_scaled ~ manner*vowel + (1 + manner|speaker),
                  data=df, control=lmerControl(optimizer="bobyqa")
)#,REML = F)
anova(mOq.2int, mOq.2int.slp)

mOq <- mOq.2int.slp # best fit

summary(mOq)
print(xtable(coef(summary(mOq)),digits=c(2,2,2,2,2,4)))

mOq.emm <- emmeans(mOq, ~ manner)
xtable(pairs(mOq.emm), digits=2)


# only for subset participants based on figure 9
df <- droplevels(subset(df, !(df$speaker %in% c("M06", "M11"))))

# excluding two participants
mOq.1 <- lmer(oq_scaled ~ manner + (1|speaker) + (1|rep),
              data=df, control=lmerControl(optimizer="bobyqa")
)#,REML = F) #singular fit

mOq.2 <- lmer(oq_scaled ~ manner + vowel + (1|speaker) + (1|rep),
              data=df, control=lmerControl(optimizer="bobyqa")
)#,REML = F)

mOq.3 <- lmer(oq_scaled ~ manner + vowel + place + (1|speaker) + (1|rep),
              data=df, control=lmerControl(optimizer="bobyqa")
)#,REML = F) # doesn't improve

mOq.4 <- lmer(oq_scaled ~ manner + vowel + place + sex + (1|speaker) + (1|rep),
              data=df, control=lmerControl(optimizer="bobyqa")
)#,REML = F) # doesn't improve

anova(mOq.1,mOq.2,mOq.3,mOq.4)

# interaction terms
mOq.2int <- lmer(oq_scaled ~ manner*vowel + (1|speaker) + (1|rep),
                 data=df, control=lmerControl(optimizer="bobyqa")
)#,REML = F)
anova(mOq.2, mOq.2int)

# random slopes
mOq.2int.slp <- lmer(oq_scaled ~ manner*vowel + (1 + manner|speaker) + (1|rep),
                     data=df, control=lmerControl(optimizer="bobyqa")
)#,REML = F)
anova(mOq.2int, mOq.2int.slp)

mOq <- mOq.2int.slp # best fit
summary(mOq)
print(xtable(coef(summary(mOq)),digits=c(2,2,2,2,2,4)))

mOq.emm <- emmeans(mOq, ~ manner)
xtable(pairs(mOq.emm), digits=2)


#####
#Scatterplots and CART analyses
#####

f0_oq_dur <- Reduce(function(x,y) merge(x = x, y = y, by = c("filename", "interval")),
                        list(f0st_Vmean, Oqscl_Vonset, VOTdat))

# normalize VOT
f0_oq_dur$VOT_scaled <- scale_by(VOTMS ~ speaker, f0_oq_dur)

# Scatterplots
pairsOqVOTcor <-
  ggscatter(f0_oq_dur[f0_oq_dur$VOTMS < 170,], x="VOT_scaled", y="oq_scaled",
          color = "manner",
          size = 3,
          alpha = 0.9,
          palette = colors_stops,
          add = "reg.line", conf.int = TRUE) + #, ellipse = TRUE, ellipse.type = "t"
  labs(x = "normalized VOT", y = "normalized Oq")  +
  ggscatter_font +
  stat_cor(aes(color = manner), label.x = -4, size = 5.5)

ggsave("./KorEGG_fig/pairsOqVOTcor.pdf", pairsOqVOTcor, width = 10, height = 8)

pairsf0VOT <-
  ggscatter(f0_oq_dur[f0_oq_dur$VOTMS < 170,], x="VOTMS", y="f0_st",
          color = "manner",
          size = 3,
          alpha = 0.9,
          palette = colors_stops,
          ellipse = TRUE,
          ellipse.type = "t") +
  ylim(-7,7) +
  labs(x = "VOT (ms)", y = "f0 (st)") +
  ggscatter_font +
  stat_cor(aes(color = manner), label.x = -4, size = 5.5)

ggsave("./KorEGG_fig/pairsf0VOT.pdf", pairsf0VOT, width = 10, height = 8)

f0_oq_dur <- droplevels(f0_oq_dur[,c("sex", "POA", "vowel", "manner", "f0_st", "oq_scaled", "VOTMS")])
colnames(f0_oq_dur) <- c("sex", "POA", "vowel", "manner", "f0 (st)", "oq_scaled", "VOT (ms)")
summary(f0_oq_dur)

# rpart: f0 in st, Oq scaled, VOT
kor_tree <- rpart(manner ~.,
                  data = f0_oq_dur,
                  method = "class",
                  control = rpart.control(cp = 0.01))
kor_tree

pdf(file = "./KorEGG_fig/CARTtree.pdf", width = 10, height = 8)
rpart.plot(kor_tree,
           box.palette = list(colors_stops[1],colors_stops[2],colors_stops[3],colors_stops[4]),
           cex=1.3,
           legend.cex=1.5)
dev.off()

cptable <- printcp(kor_tree)
print(xtable(cptable))

plotcp(kor_tree)

conf.matrix <- table(f0_oq_dur$manner, predict(kor_tree, type = "class"))
rownames(conf.matrix) <- paste("Actual", rownames(conf.matrix), sep = ":")
colnames(conf.matrix) <- paste("Pred", colnames(conf.matrix), sep = ":")
print(conf.matrix)
prop.table(conf.matrix,2)

print(xtable(conf.matrix))

#####
#Nasality analyses: spectral moments, and C-V intensity
#####

nasdat.orig <- read.table("KorEGG_nasal_spectralMoments_20200924.txt",
                           header=T, sep="\t", comment.char="", encoding="UTF-8")

nasdatall <-
  nasdat.orig %>%
  rename(interval = onsetInterval) %>%
  separate(
    col = filename,
    into = c("speaker", "sex", "repetition", "position", "onset"),
    remove = FALSE) %>%
  mutate(onsetDur = onsetDur*1000) %>%
  mutate(speaker = paste0(sex, substr(speaker, 3, 4))) %>%
  mutate(onset = recode_factor("mm" = "m", "nn" = "n", onset)) %>%
  mutate(position = recode_factor("0CV" = "initial", "aCV" = "medial", position)) %>%
  mutate_if(is.character, factor)

# Duration plot: pooled
figNasDur <- nasdatall %>% ggplot(aes(x=position, y=onsetDur, fill=position)) +
  geom_violin(trim=TRUE) +
  geom_boxplot(width=0.2, color="white", outlier.size = 0.5, position="dodge") +
  labs(y = "nasal duration (ms)") +
  theme(legend.position = 'none') +
  ggtitle("Duration")
#  facet_grid(.~onset)
ggsave("./KorEGG_fig/FigNasDur.pdf", figNasDur, width = 5, height = 4)

# Duration plot: by speaker
figNasDursp <- nasdatall %>% ggplot(aes(x=position, y=onsetDur, fill=position)) +
  geom_violin(trim=TRUE) +
  geom_boxplot(width=0.15, color="white", outlier.size = 0.5, position="dodge") +
  labs(y = "nasal duration (ms)") +
  theme(legend.position = 'none') +
  ggtitle("Duration") +
  facet_wrap(.~speaker)
ggsave("./KorEGG_fig/FigNasDursp.pdf", figNasDursp, width = 10, height = 10)

# eliminate devoiced nasals based on VOT results and remove duration > 30 ms
nasdat <-
  nasdatall %>%
  anti_join(., devnas, by = c("filename", "interval")) %>%
  select(speaker, position, onset, onsetDur, CenterOfGravity, stdv, skewness, kurtosis, onset2vowelDB) %>%
  mutate_if(is.character, factor) %>%
  filter(onsetDur > 0.03)

# C-V intensity plot: pooled
figNasDB <- nasdat %>% ggplot(aes(x=position, y=onset2vowelDB, fill=position)) +
  geom_violin(trim=TRUE) +
  geom_boxplot(width=0.2, color="white", outlier.size = 0.5, position="dodge") +
  labs(y = "relative intensity to V (dB)") +
  theme(legend.position = 'none') +
  ylim(-30,10) +
  ggtitle("Intensity")
 # facet_grid(.~onset)
ggsave("./KorEGG_fig/FigNasDB.pdf", figNasDB, width = 5, height = 4)

# C-V intensity plot: by speaker
figNasDBsp <- nasdat %>% ggplot(aes(x=position, y=onset2vowelDB, fill=position)) +
  geom_violin(trim=TRUE) +
  geom_boxplot(width=0.2, color="white", outlier.size = 0.5, position="dodge") +
  labs(y = "relative intensity to V (dB)") +
  theme(legend.position = 'none') +
  ggtitle("Intensity") +
  facet_wrap(.~speaker, scales = "free")
ggsave("./KorEGG_fig/FigNasDBsp.pdf", figNasDBsp, width = 10, height = 10)

## Spectral moments for nasals
# CoG plot: by speaker
figNasCoGsp <- nasdat %>% ggplot(aes(x=position, y=CenterOfGravity, fill=position)) +
  geom_violin(trim=TRUE) +
  geom_boxplot(width=0.2, color="white", outlier.size = 0.5, position="dodge") +
  labs(y = "CoG") +
  theme(legend.position = 'none') +
  ggtitle("Center of Gravity") +
  facet_wrap(.~speaker, scales = "free")
ggsave("./KorEGG_fig/FigNasCoGsp.pdf", figNasCoGsp, width = 10, height = 10)

# standard deviation plot: by speaker
figNasstdvsp <- nasdat %>% ggplot(aes(x=position, y=stdv, fill=position)) +
  geom_violin(trim=TRUE) +
  geom_boxplot(width=0.2, color="white", outlier.size = 0.5, position="dodge") +
  labs(y = "Standard deviation") +
  theme(legend.position = 'none') +
  ggtitle("Standard deviation") +
  facet_wrap(.~speaker, scales = "free")
ggsave("./KorEGG_fig/FigNasstdvsp.pdf", figNasstdvsp, width = 10, height = 10)

# skewness plot: by speaker
figNasSkewsp <- nasdat %>% ggplot(aes(x=position, y=skewness, fill=position)) +
  geom_violin(trim=TRUE) +
  geom_boxplot(width=0.2, color="white", outlier.size = 0.5, position="dodge") +
  labs(y = "Skewness") +
  theme(legend.position = 'none') +
  ggtitle("Skewness") +
  facet_wrap(.~speaker, scales = "free")
ggsave("./KorEGG_fig/FigNasSkewsp.pdf", figNasSkewsp, width = 10, height = 10)

# kurtosis plot: by speaker
figNasKurtsp <- nasdat %>% ggplot(aes(x=position, y=kurtosis, fill=position)) +
  geom_violin(trim=TRUE) +
  geom_boxplot(width=0.2, color="white", outlier.size = 0.5, position="dodge") +
  labs(y = "Kurtosis") +
  theme(legend.position = 'none') +
  ggtitle("Kurtosis") +
  facet_wrap(.~speaker, scales = "free")
ggsave("./KorEGG_fig/FigNasKurtsp.pdf", figNasKurtsp, width = 10, height = 10)

